@@ -7,7 +7,6 @@
 #pragma once
 
 #include <gio/gio.h>
-#include <glib-object.h>
 
 #include "fwupd-device.h"
 #include "fwupd-enums.h"
@@ -80,6 +79,8 @@ gboolean
 fwupd_client_connect_finish(FwupdClient *self,
 			    GAsyncResult *res,
 			    GError **error) G_GNUC_WARN_UNUSED_RESULT;
+gboolean
+fwupd_client_disconnect(FwupdClient *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
 fwupd_client_get_devices_async(FwupdClient *self,
 			       GCancellable *cancellable,
@@ -364,17 +365,27 @@ fwupd_client_get_status(FwupdClient *self);
 gboolean
 fwupd_client_get_tainted(FwupdClient *self);
 gboolean
+fwupd_client_get_only_trusted(FwupdClient *self);
+gboolean
 fwupd_client_get_daemon_interactive(FwupdClient *self);
 guint
 fwupd_client_get_percentage(FwupdClient *self);
 const gchar *
 fwupd_client_get_daemon_version(FwupdClient *self);
 const gchar *
+fwupd_client_get_host_bkc(FwupdClient *self);
+const gchar *
+fwupd_client_get_host_vendor(FwupdClient *self);
+const gchar *
 fwupd_client_get_host_product(FwupdClient *self);
 const gchar *
 fwupd_client_get_host_machine_id(FwupdClient *self);
 const gchar *
 fwupd_client_get_host_security_id(FwupdClient *self);
+guint32
+fwupd_client_get_battery_level(FwupdClient *self);
+guint32
+fwupd_client_get_battery_threshold(FwupdClient *self);
 
 void
 fwupd_client_get_remotes_async(FwupdClient *self,
