@@ -597,6 +597,14 @@ typedef guint64 FwupdDeviceFlags;
  * Since 1.8.1
  */
 #define FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED (1u << 5)
+/**
+ * FWUPD_DEVICE_PROBLEM_IS_EMULATED:
+ *
+ * The device is emulated from a different host.
+ *
+ * Since 1.8.3
+ */
+#define FWUPD_DEVICE_PROBLEM_IS_EMULATED (1u << 6)
 /**
  * FWUPD_DEVICE_PROBLEM_UNKNOWN:
  *
